/**
 * OW2 Util
 * Copyright (C) 2008 Bull S.A.S.
 * Contact: easybeans@objectweb.org
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307
 * USA
 *
 * --------------------------------------------------------------------------
 * $Id: ArchiveMetadataImpl.java 3981 2008-09-28 11:42:25Z benoitf $
 * --------------------------------------------------------------------------
 */

package org.ow2.util.archive.impl;

import java.util.HashMap;
import java.util.Map;

import org.ow2.util.archive.api.IArchiveMetadata;

/**
 * Implementation of the metadata interface of an archive.
 * @author Florent BENOIT
 */
public class ArchiveMetadataImpl implements IArchiveMetadata {

    /**
     * Map that will store the entries.
     */
    private Map<String, String> entries;

    /**
     * Default constructor.
     */
    public ArchiveMetadataImpl() {
        // init the map
        this.entries = new HashMap<String, String>();
    }

    /**
     * Gets the value of an entry for the given name.
     * @param name the name of the key to use.
     * @return the value
     */
    public String get(final String name) {
        return entries.get(name);
    }

    /**
     * @return the value of the implementation version of this archive.
     */
    public String getImplementationVersion() {
        return entries.get(java.util.jar.Attributes.Name.IMPLEMENTATION_VERSION.toString());
    }

    /**
     * Adds an entry into this metadata.
     * @param name the name of the key to add
     * @param value the value of the given key
     */
    public void put(final String name, final String value) {
        entries.put(name, value);
    }
}
